pub enum BridgeWarrantPolicy {
SharedTrust,
Verify,
}Expand description
Policy for checking packet warrants at receive time.
Variants
The receiver already trusts that it shares the sender’s books.
Verify
The receiver checks packet warrant content ids against its local books.