pub enum ReplyRule {
Opens,
Any,
AnyNonReceipt,
Only(Vec<Symbol>),
}Expand description
Parent-intent rule for a BRIDGE move.
Variants
Opens
The move opens a new thread and may not cite parents.
Any
The move may answer any parent intent.
AnyNonReceipt
The move may answer any parent intent except receipt.
Only(Vec<Symbol>)
The move may answer only the listed parent intents.