pub fn assert_roundtrip(packet: &BridgePacket, book: &BridgeBook) -> Result<()>Expand description
Asserts that encoding then decoding reproduces the same packet.
pub fn assert_roundtrip(packet: &BridgePacket, book: &BridgeBook) -> Result<()>Asserts that encoding then decoding reproduces the same packet.