pub fn canonical_packet_datum(packet: &BridgePacket) -> DatumExpand description
Builds the canonical datum for hashing a packet with cid cleared.
pub fn canonical_packet_datum(packet: &BridgePacket) -> DatumBuilds the canonical datum for hashing a packet with cid cleared.