pub fn frame_book_content_id(book: &BridgeFrameBook) -> Result<ContentId>Expand description
Computes the content id for a fluent frame book registry record.
pub fn frame_book_content_id(book: &BridgeFrameBook) -> Result<ContentId>Computes the content id for a fluent frame book registry record.