pub fn move_book_content_id(book: &BridgeMoveBook) -> Result<ContentId>Expand description
Computes the content id for a dialogue move book registry record.
pub fn move_book_content_id(book: &BridgeMoveBook) -> Result<ContentId>Computes the content id for a dialogue move book registry record.