pub fn packet_content_id(packet: &BridgePacket) -> Result<ContentId>Expand description
Computes the canonical content id for a packet with cid cleared.
pub fn packet_content_id(packet: &BridgePacket) -> Result<ContentId>Computes the canonical content id for a packet with cid cleared.