pub fn packet_to_expr(packet: &BridgePacket) -> ExprExpand description
Project a packet to the canonical expression record used by codec:bridge.
pub fn packet_to_expr(packet: &BridgePacket) -> ExprProject a packet to the canonical expression record used by codec:bridge.