pub fn stamp_packet_cid(packet: &BridgePacket) -> Result<BridgePacket>Expand description
Returns a packet with its canonical cid stamped into the header.
pub fn stamp_packet_cid(packet: &BridgePacket) -> Result<BridgePacket>Returns a packet with its canonical cid stamped into the header.