BridgeBook

Struct BridgeBook 

pub struct BridgeBook {
    pub parts: BridgePartBook,
    pub moves: BridgeMoveBook,
    pub frames: BridgeFrameBook,
    pub profiles: BridgeProfileBook,
    pub warrant_policy: BridgeWarrantPolicy,
}
A BRIDGE book bundles the part book and move book used for a packet.

Fields

parts: BridgePartBook

Registered part-kind specs.

moves: BridgeMoveBook

Registered dialogue move specs.

frames: BridgeFrameBook

Registered fluent frame specs.

profiles: BridgeProfileBook

Registered packet profile specs.

warrant_policy: BridgeWarrantPolicy

Policy for warrant verification by receivers using this book.

Implementations

Source

impl BridgeBook

pub fn new( parts: BridgePartBook, moves: BridgeMoveBook, frames: BridgeFrameBook, profiles: BridgeProfileBook, ) -> Self

Builds a book from explicit part, move, frame, and profile books.

pub fn standard() -> Self

Builds the standard BRIDGE book.

pub fn with_part(self, spec: BridgePartSpec) -> Self

Returns a copy with one more part spec registered.

pub fn with_frame(self, spec: FrameSpec) -> Self

Returns a copy with one more frame spec registered.

pub fn with_profile(self, spec: BridgeProfileSpec) -> Self

Returns a copy with one more profile spec registered.

pub fn with_warrant_policy(self, policy: BridgeWarrantPolicy) -> Self

Returns a copy with the warrant verification policy set.