BridgeHeader

Struct BridgeHeader 

pub struct BridgeHeader {
    pub cid: Option<String>,
    pub move_kind: Symbol,
    pub from: String,
    pub to: Vec<String>,
    pub role: Symbol,
    pub parents: Vec<String>,
    pub task: Symbol,
    pub output: Symbol,
    pub ceiling: Vec<Symbol>,
    pub context: Vec<Symbol>,
    pub provenance: BridgeProvenance,
}
Fixed, fast-scan BRIDGE packet header.

Fields

cid: Option<String>

Packet content id as rendered text, or None while canonicalizing.

move_kind: Symbol

Dialogue move intent.

from: String

Sender seat.

to: Vec<String>

Receiver seats.

role: Symbol

Sender role for this packet.

parents: Vec<String>

Parent packet content ids.

task: Symbol

Header task part id.

output: Symbol

Header output/return part id.

ceiling: Vec<Symbol>

Capability ceiling names, resolved by later bridge runtime code.

context: Vec<Symbol>

Context part ids available to this packet.

provenance: BridgeProvenance

Packet provenance.