pub struct BridgeVotePayload {
pub target: String,
pub scores: Vec<BridgeScore>,
}Expand description
Vote payload with one or more structured score axes.
Fields
target: StringTarget packet path or contribution id being voted on.
scores: Vec<BridgeScore>Structured score axes.
Implementations