pub struct BridgeWarrant {
pub moves: ContentId,
pub frames: ContentId,
pub parts: Vec<(Symbol, ContentId)>,
}Expand description
Content ids of protocol books and part specs used to build a packet.
Fields
moves: ContentIdContent id of the dialogue move book.
frames: ContentIdContent id of the fluent frame book.
parts: Vec<(Symbol, ContentId)>Content ids of the part specs used by this packet, keyed by part kind.