pub enum FrameHoleKind {
Ref,
Term,
Choice,
Path,
Number,
Prose,
}Expand description
Hole kind for a typed BRIDGE frame slot.
Variants
Ref
A reference to another packet part or external object.
Term
A symbolic term.
Choice
A closed choice token.
Path
A structured path.
Number
A numeric value.
Prose
Prose data that must be rendered through a fence.
Implementations
Sourceimpl FrameHoleKind
impl FrameHoleKind
Sourcepub fn shape_expr(self) -> Expr
pub fn shape_expr(self) -> Expr
Shape descriptor for values accepted by this hole kind.