pub struct BridgeBook {
pub parts: BridgePartBook,
pub moves: BridgeMoveBook,
pub frames: BridgeFrameBook,
pub profiles: BridgeProfileBook,
pub warrant_policy: BridgeWarrantPolicy,
}Expand description
A BRIDGE book bundles the part book and move book used for a packet.
Fields
parts: BridgePartBookRegistered part-kind specs.
moves: BridgeMoveBookRegistered dialogue move specs.
frames: BridgeFrameBookRegistered fluent frame specs.
profiles: BridgeProfileBookRegistered packet profile specs.
warrant_policy: BridgeWarrantPolicyPolicy for warrant verification by receivers using this book.
Implementations
Sourceimpl BridgeBook
impl BridgeBook
Sourcepub fn new(
parts: BridgePartBook,
moves: BridgeMoveBook,
frames: BridgeFrameBook,
profiles: BridgeProfileBook,
) -> Self
pub fn new( parts: BridgePartBook, moves: BridgeMoveBook, frames: BridgeFrameBook, profiles: BridgeProfileBook, ) -> Self
Builds a book from explicit part, move, frame, and profile books.
Sourcepub fn with_part(self, spec: BridgePartSpec) -> Self
pub fn with_part(self, spec: BridgePartSpec) -> Self
Returns a copy with one more part spec registered.
Sourcepub fn with_frame(self, spec: FrameSpec) -> Self
pub fn with_frame(self, spec: FrameSpec) -> Self
Returns a copy with one more frame spec registered.
Sourcepub fn with_profile(self, spec: BridgeProfileSpec) -> Self
pub fn with_profile(self, spec: BridgeProfileSpec) -> Self
Returns a copy with one more profile spec registered.
Sourcepub fn with_warrant_policy(self, policy: BridgeWarrantPolicy) -> Self
pub fn with_warrant_policy(self, policy: BridgeWarrantPolicy) -> Self
Returns a copy with the warrant verification policy set.