pub struct BridgePacket {
pub header: BridgeHeader,
pub body: Vec<BridgePart>,
pub warrant: Option<BridgeWarrant>,
}Expand description
One BRIDGE packet, carrying a header, ordered typed parts, and optional warrant.
Fields
header: BridgeHeaderFixed packet header.
body: Vec<BridgePart>Ordered packet body parts.
warrant: Option<BridgeWarrant>Optional cross-trust warrant for book and spec content ids.
Implementations
Sourceimpl BridgePacket
impl BridgePacket
Sourcepub fn canonicalized(&self) -> Self
pub fn canonicalized(&self) -> Self
Returns this packet with its header cid cleared for canonical hashing.